#include "DSP28x_Project.h"
void I2C_Init(void);
void I2C_Write(Uint16 reg_address, Uint16 data);
Uint16 I2C_Read(Uint16 reg_address);


#define SLAVE_ADDR            0x53 //ADXL345 -> if ALT_ADDRESS pin is grounded!
#define Register_2D           0x2D
#define Register_X0           0x32
#define Register_X1           0x33
#define Register_Y0           0x34
#define Register_Y1           0x35
#define Register_Z0           0x36
#define Register_Z1           0x37


Uint16 DATA[6];


void main(void)
{
    Uint16 i;
    InitSysCtrl();
    InitI2CGpio();
    DINT;
    InitPieCtrl();
// Disable CPU interrupts and clear all CPU interrupt flags:
   IER = 0x0000;
   IFR = 0x0000;
   InitPieVectTable();

   I2C_Init();
   for(i=0;i<2;i++)
   {
       DATA[i]=0x0000;
   }

   EINT;
//   I2C_Write(Register_2D, 0x00);			// send data 0x00 to register address 2D (standby mode)
   
   I2C_Write(Register_2D, 0x08);			// send data 0x00 to register address 2D (measure mode)
   
   for(;;)
   {
       DATA[0] = I2C_Read(Register_X0);	// read register address X0
	   DATA[1] = I2C_Read(Register_X1);	// read register address X1
	   DATA[2] = I2C_Read(Register_Y0);	// read register address Y0
	   DATA[3] = I2C_Read(Register_Y1);	// read register address Y1
	   DATA[4] = I2C_Read(Register_Z0);	// read register address Z0
	   DATA[5] = I2C_Read(Register_Z1);	// read register address Z1
   }   // end of for(;;)
}   // end of main
void I2C_Init(void)
{
   // Initialize I2C
   I2caRegs.I2CMDR.all 	= 0x0020;
   I2caRegs.I2CSAR = SLAVE_ADDR;// Slave address - EEPROM control code
  
   #if (CPU_FRQ_150MHZ)             // Default - For 150MHz SYSCLKOUT
        I2caRegs.I2CPSC.all = 14;   // Prescaler - need 7-12 Mhz on module clk (150/15 = 10MHz)
   #endif
   #if (CPU_FRQ_100MHZ)             // For 100 MHz SYSCLKOUT
     I2caRegs.I2CPSC.all = 9;       // Prescaler - need 7-12 Mhz on module clk (100/10 = 10MHz)
   #endif
   I2caRegs.I2CCLKL = 10;           // NOTE: must be non zero
   I2caRegs.I2CCLKH = 5;            // NOTE: must be non zero

   I2caRegs.I2CMDR.all = 0x0020;    // Take I2C out of reset
                                    // Stop I2C when suspended
                                    // I2caRegs.I2CMDR.all = 0000 0010 0000 0000
   I2caRegs.I2CFFTX.all = 0x6000;   // Enable FIFO mode and TXFIFO
   I2caRegs.I2CFFRX.all = 0x2040;   // Enable RXFIFO, clear RXFFINT,
   return;
}
void I2C_Write(Uint16 reg_address, Uint16 data)
{
	I2caRegs.I2CMDR.bit.IRS = 1; 			// reset I2C
	
	I2caRegs.I2CSAR = SLAVE_ADDR;           // I2C slave address
	while (I2caRegs.I2CSTR.bit.BB == 1);	// still busy?
	
    I2caRegs.I2CCNT = 2;					// assume register address = 1 byte, and data is 1 byte
	
    I2caRegs.I2CDXR = reg_address;			// register address of the sensor (1 byte)
    I2caRegs.I2CDXR = data;					// data to be sent (1 byte)
	
	I2caRegs.I2CMDR.all = 0x2E20; 			// start, stop, no rm, reset i2c
	
	I2caRegs.I2CMDR.bit.STP = 1;  			// stop bit when CNT=0
    
    while(!I2caRegs.I2CSTR.bit.SCD);       // wait for STOP condition

	
	return;

}


Uint16 I2C_Read(Uint16 reg_address)
{
	Uint16 tempdata;

	I2caRegs.I2CMDR.bit.IRS = 1; 				// reset I2C
	
	// Make sure I2C is not busy and has stopped
	I2caRegs.I2CMDR.bit.IRS = 1; 				// reset I2C
	while (I2caRegs.I2CSTR.bit.BB == 1);		// busy loop
	I2caRegs.I2CSTR.bit.SCD = 1;				// Clear the SCD bit (stop condition bit)
	while(I2caRegs.I2CMDR.bit.STP == 1);		// stop bit loop
	
	I2caRegs.I2CSAR 	= SLAVE_ADDR;			// I2C slave address

	while (I2caRegs.I2CSTR.bit.BB == 1);		// still busy?
	
	I2caRegs.I2CMDR.all = 0x2620;				// start, no stop bit, master, tx, reset I2C
	I2caRegs.I2CCNT		= 1;					// assume register address is one byte
	I2caRegs.I2CDXR		= reg_address;			// register address of the sensor (1 byte)

	while(!I2caRegs.I2CSTR.bit.ARDY);			// all ready?

	I2caRegs.I2CMDR.all = 0x2C20;				// start, stop bit when CNT =0, master, rx, reset I2C
	I2caRegs.I2CCNT		= 1;					// only read one byte data

	if(I2caRegs.I2CSTR.bit.NACK == 1)
	{
		 I2caRegs.I2CSTR.all = I2C_CLR_NACK_BIT; 	// 0x0002
	}
	I2caRegs.I2CMDR.bit.STP = 1;					// stop bit when CNT=0

	while(!I2caRegs.I2CSTR.bit.SCD);				// stop bit detected?

				
	tempdata	= I2caRegs.I2CDRR;					// read one byte data


	return(tempdata);
 
}
i
//==================== =======================================================
// No more.
//===========================================================================